@@ -13,6 +13,7 @@ import (
 
 type IdentifiedResourcesListOpts struct {
 	IgnoreCachedResTypes bool
+	GKsScope             []schema.GroupKind
 }
 
 func (r IdentifiedResources) List(labelSelector labels.Selector, resRefs []ResourceRef, opts IdentifiedResourcesListOpts) ([]Resource, error) {
@@ -36,6 +37,10 @@ func (r IdentifiedResources) List(labelSelector labels.Selector, resRefs []Resou
 		schema.GroupVersionResource{Version: "v1", Resource: "componentstatuses"},
 	})
 
+	if len(opts.GKsScope) > 0 {
+		resTypes = MatchingAnyGK(resTypes, opts.GKsScope)
+	}
+
 	if len(resRefs) > 0 {
 		resTypes = MatchingAny(resTypes, resRefs)
 	}
